@@ -12,6 +12,10 @@ class BaseFeedbackForm(forms.Form):
     class Media:
         js = ((settings.MEDIA_URL + 'feedback/js/feedback.js'),)
 
+    subject = _('feedback')
+    
+    serialized_fields = ()
+
     def __init__(self, *args, **kwds):
         '''Overriden: Creates additional form key hidden field'''
         super(BaseFeedbackForm, self).__init__(*args, **kwds)
@@ -22,19 +26,21 @@ class BaseFeedbackForm(forms.Form):
             initial=self.get_settings_key,
         )
 
-    def mail(self):
+    def mail(self, request):
         # prepare context for message
+        context = self.get_context_data(request)
+        message = render_to_string(self.get_template(), context)
+        mail_managers(self.subject, message, fail_silently=False)
+
+    def get_context_data(self, request):
         context = {'fields': {}}
         for name, field in self.fields.iteritems():
             context['fields'][name] = self.cleaned_data.get(name, None)
-            # leaved for compatibility. Wil be removed in feedback v 1.2
+            # leaved for compatibility. Will be removed in feedback v 1.2
             context[name] = self.cleaned_data.get(name, None)
         context['form'] = self
-        message = render_to_string(self.get_template(), context)
-
-        # generate subject considering settings variable EMAIL_SUBJECT_PREFIX
-        subject = _('feedback')
-        mail_managers(subject, message, fail_silently=False)
+        context['request'] = request
+        return context
 
     def get_settings_key(self):
         '''Finds self class in settings.FEEDBACK_FORMS dictionary
@@ -77,6 +83,21 @@ class BaseFeedbackForm(forms.Form):
             return template_name
         except TemplateDoesNotExist:
             return 'feedback/feedback_message.txt'
+        
+    def get_dictionary(self):
+        
+        if (self.is_valid()):
+            field_dictionary = {'subject': self.subject}
+            
+            counter = 0
+            for field in self.serialized_fields:
+#                field_dictionary[self[field].label] = self.cleaned_data[field]
+                field_dictionary[str(counter)] = {
+                    'key':self[field].label,
+                    'value':self.cleaned_data[field]}
+                counter += 1
+                
+            return field_dictionary
 
 
 class FeedbackForm(BaseFeedbackForm):
@@ -85,3 +106,5 @@ class FeedbackForm(BaseFeedbackForm):
     response = forms.CharField(label=_('Message text'), max_length=500,
         widget=forms.Textarea(attrs={'cols':'30', 'rows':'5'}))
     subject = _('Feedback form')
+    
+    serialized_fields = ('email', 'topic', 'response',)
